@@ -17,7 +17,7 @@ def exec_(code, glob):
 TREE_FACTOR = 1 # increase tree size with '-l / '-L' cmd option
 
 _TEXT  = "some ASCII text" * TREE_FACTOR
-_UTEXT = u"some klingon: \F8D2" * TREE_FACTOR
+_UTEXT = u"some klingon: \uF8D2" * TREE_FACTOR
 _ATTRIBUTES = {
     '{attr}test1' : _TEXT,
     '{attr}test2' : _TEXT,
