@@ -282,7 +282,8 @@ def seems_to_have_libxml2():
 
 def print_libxml_error():
     print('*********************************************************************************')
-    print('Could not find function xmlCheckVersion in library libxml2. Is libxml2 installed?')
+    print("Could not find function xmlXPathInit in library libxml2. Is libxml2 installed?")
+    print("Is your C compiler installed and configured correctly?")
     if sys.platform in ('darwin',):
         print('Perhaps try: xcode-select --install')
     print('*********************************************************************************')
@@ -352,13 +353,6 @@ def cflags(static_cflags):
             if not possible_cflag.startswith('-I'):
                 result.append(possible_cflag)
 
-    if sys.platform in ('darwin',):
-        for opt in result:
-            if 'flat_namespace' in opt:
-                break
-        else:
-            result.append('-flat_namespace')
-
     return result
 
 def define_macros():
